@@ -1,17 +1,18 @@
 from dotenv import find_dotenv, load_dotenv
-from init import init
 from langchain import hub
 from langchain.agents import AgentExecutor, create_openai_functions_agent
 from langchain.chains import LLMMathChain
 from langchain_core.pydantic_v1 import BaseModel, Field
 from langchain_core.tools import Tool
 from langchain_openai import ChatOpenAI
-from utils.with_root_span import with_langtrace_root_span
 
+from src.langtrace_python_sdk import langtrace
+from src.utils.with_root_span import with_langtrace_root_span
 
 _ = load_dotenv(find_dotenv())
 
-init()
+langtrace.init(batch=True, log_spans_to_console=True,
+               write_to_remote_url=False)
 
 
 llm = ChatOpenAI(temperature=0, model="gpt-4")
